==> igniteui-react-18.2.2-beta.0.tgz: package/esm2015/lib/DateTimeInput.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { MaskInputBase } from "./MaskInputBase";
import { enumGetBox, markType } from "igniteui-react-core";
import { DatePartDeltas } from "./DatePartDeltas";
import { ComponentDateValueChangedEventArgs } from "./ComponentDateValueChangedEventArgs";
import { DatePart_$type } from "./DatePart";
/**
 * @hidden
 */
export let DateTimeInput = /*@__PURE__*/ (() => {
    class DateTimeInput extends MaskInputBase {
        constructor() {
            super(...arguments);
            this.change = null;
        }
        get al() {
            let ret_ = this.f.m("inputFormat");
            return ret_;
        }
        set al(a) {
            let value_ = a;
            this.f.u("inputFormat", value_);
        }
        get aj() {
            let ret_ = this.f.m("value");
            return ret_;
        }
        set aj(a) {
            let value_ = a;
            this.f.u("value", value_);
        }
        get ai() {
            let ret_ = this.f.m("minValue");
            return ret_;
        }
        set ai(a) {
            let value_ = a;
            this.f.u("minValue", value_);
        }
        get ah() {
            let ret_ = this.f.m("maxValue");
            return ret_;
        }
        set ah(a) {
            let value_ = a;
            this.f.u("maxValue", value_);
        }
        get ak() {
            let ret_ = this.f.m("displayFormat");
            return ret_;
        }
        set ak(a) {
            let value_ = a;
            this.f.u("displayFormat", value_);
        }
        get af() {
            let ret_ = this.f.l("spinDelta", (a) => new DatePartDeltas());
            return ret_;
        }
        set af(a) {
            let value_ = a;
            this.f.u("spinDelta", value_);
        }
        get ag() {
            let ret_ = this.f.m("spinLoop");
            return ret_;
        }
        set ag(a) {
            let value_ = a;
            this.f.u("spinLoop", value_);
        }
        get am() {
            let ret_ = this.f.m("locale");
            return ret_;
        }
        set am(a) {
            let value_ = a;
            this.f.u("locale", value_);
        }
        changeChanged() {
            if (this.change != null) {
                this.f.q("change", (a) => this.change(this, ComponentDateValueChangedEventArgs.a(a)));
            }
            else {
                this.f.t("change");
            }
        }
        aq() {
            this.nativeElement.connectedCallback();
        }
        ar() {
            this.nativeElement.reportValidity();
        }
        ao() {
            this.nativeElement.checkValidity();
        }
        at(a, b) {
            this.nativeElement.stepUp(this.f.h(enumGetBox(DatePart_$type, a)), this.f.h(b));
        }
        as(a, b) {
            this.nativeElement.stepDown(this.f.h(enumGetBox(DatePart_$type, a)), this.f.h(b));
        }
        ap() {
            this.nativeElement.clear();
        }
    }
    DateTimeInput.$t = /*@__PURE__*/ markType(DateTimeInput, 'DateTimeInput', MaskInputBase.$);
    return DateTimeInput;
})();

==> igniteui-react-18.5.2-beta.0.tgz: package/esm2015/lib/DateTimeInput.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { MaskInputBase } from "./MaskInputBase";
import { enumGetBox, markType } from "igniteui-react-core";
import { DatePartDeltas } from "./DatePartDeltas";
import { ComponentDateValueChangedEventArgs } from "./ComponentDateValueChangedEventArgs";
import { DatePart_$type } from "./DatePart";
/**
 * @hidden
 */
export let DateTimeInput = /*@__PURE__*/ (() => {
    class DateTimeInput extends MaskInputBase {
        constructor() {
            super(...arguments);
            this.change = null;
        }
        get ao() {
            let ret_ = this.f.n("inputFormat");
            return ret_;
        }
        set ao(a) {
            let value_ = a;
            this.f.v("inputFormat", value_);
        }
        get am() {
            let ret_ = this.f.n("value");
            return ret_;
        }
        set am(a) {
            let value_ = a;
            this.f.v("value", value_);
        }
        get ak() {
            let ret_ = this.f.n("min");
            return ret_;
        }
        set ak(a) {
            let value_ = a;
            this.f.v("min", value_);
        }
        get ai() {
            let ret_ = this.f.n("max");
            return ret_;
        }
        set ai(a) {
            let value_ = a;
            this.f.v("max", value_);
        }
        get al() {
            let ret_ = this.f.n("minValue");
            return ret_;
        }
        set al(a) {
            let value_ = a;
            this.f.v("minValue", value_);
        }
        get aj() {
            let ret_ = this.f.n("maxValue");
            return ret_;
        }
        set aj(a) {
            let value_ = a;
            this.f.v("maxValue", value_);
        }
        get an() {
            let ret_ = this.f.n("displayFormat");
            return ret_;
        }
        set an(a) {
            let value_ = a;
            this.f.v("displayFormat", value_);
        }
        get ag() {
            let ret_ = this.f.m("spinDelta", (a) => new DatePartDeltas());
            return ret_;
        }
        set ag(a) {
            let value_ = a;
            this.f.v("spinDelta", value_);
        }
        get ah() {
            let ret_ = this.f.n("spinLoop");
            return ret_;
        }
        set ah(a) {
            let value_ = a;
            this.f.v("spinLoop", value_);
        }
        get ap() {
            let ret_ = this.f.n("locale");
            return ret_;
        }
        set ap(a) {
            let value_ = a;
            this.f.v("locale", value_);
        }
        changeChanged() {
            if (this.change != null) {
                this.f.r("change", (a) => this.change(this, ComponentDateValueChangedEventArgs.a(a)));
            }
            else {
                this.f.u("change");
            }
        }
        as() {
            this.nativeElement.connectedCallback();
        }
        au(a, b = -1) {
            this.nativeElement.stepUp(this.f.i(enumGetBox(DatePart_$type, a)), this.f.i(b));
        }
        at(a, b = -1) {
            this.nativeElement.stepDown(this.f.i(enumGetBox(DatePart_$type, a)), this.f.i(b));
        }
        ar() {
            this.nativeElement.clear();
        }
    }
    DateTimeInput.$t = /*@__PURE__*/ markType(DateTimeInput, 'DateTimeInput', MaskInputBase.$);
    return DateTimeInput;
})();
